Products.zms.IZMSFormatProvider.IZMSFormatProvider

Package Products :: Package zms :: Module IZMSFormatProvider :: Class IZMSFormatProvider |
[frames] | no frames]

# Class IZMSFormatProvider

    zope.interface.Interface --+
                               |
                              IZMSFormatProvider

Instance Methods
`string` |
getTextFormatDefault(self) Returns id of default text-format |
getTextFormat(self, id, REQUEST) Returns text-format specified by given id |
`list` |
getTextFormats(self, REQUEST) Returns list of all text-formats |
`list` |
getCharFormats(self) Returns list of all character-formats |

Method Details

### getTextFormat(self, id, REQUEST) |
Returns text-format specified by given id Parameters: `REQUEST` (ZPublisher.HTTPRequest) - the triggering request

### getTextFormats(self, REQUEST) |
Returns list of all text-formats Parameters: `REQUEST` (ZPublisher.HTTPRequest) - the triggering request Returns: `list`